@@ -14,10 +14,11 @@
 #' @return A vector of Cook's distance values for each observation from the
 #'   fitted model object.
 #'
-#' @method cooks.distance spmod
+#' @name cooks.distance.spmodel
+#' @method cooks.distance splm
 #' @export
 #'
-#' @seealso [hatvalues.spmod()] [influence.spmod()] [residuals.spmod()]
+#' @seealso [hatvalues.spmodel()] [influence.spmodel()] [residuals.spmodel()]
 #'
 #' @examples
 #' spmod <- splm(z ~ water + tarp,
@@ -25,6 +26,11 @@
 #'   spcov_type = "exponential", xcoord = x, ycoord = y
 #' )
 #' cooks.distance(spmod)
-cooks.distance.spmod <- function(model, ...) {
+cooks.distance.splm <- function(model, ...) {
   model$cooks_distance
 }
+
+#' @rdname cooks.distance.spmodel
+#' @method cooks.distance spautor
+#' @export
+cooks.distance.spautor <- cooks.distance.splm
