@@ -6,14 +6,15 @@
 #'   where \code{estmethod} is \code{"ml"} or \code{"reml"}.
 #' @param ... Other arguments. Not used (needed for generic consistency).
 #'
-#' @details For \code{spmod} objects estimated using \code{"ml"} or \code{"reml"},
+#' @details For objects estimated using \code{"ml"} or \code{"reml"},
 #'   the deviance is \eqn{(y - X \beta)^T V (y - X \beta)} for an inverse
 #'   covariance matrix \eqn{V}, analogous
 #'   to residual sums of (whitened) squares.
 #'
 #' @return The deviance.
 #'
-#' @method deviance spmod
+#' @name deviance.spmodel
+#' @method deviance splm
 #' @export
 #'
 #' @examples
@@ -22,7 +23,7 @@
 #'   spcov_type = "exponential", xcoord = x, ycoord = y
 #' )
 #' deviance(spmod)
-deviance.spmod <- function(object, ...) {
+deviance.splm <- function(object, ...) {
   if (object$estmethod %in% c("reml", "ml")) {
     deviance <- object$deviance
     return(deviance)
@@ -30,3 +31,8 @@ deviance.spmod <- function(object, ...) {
     stop("deviance is only defined for reml or ml estimation")
   }
 }
+
+#' @rdname deviance.spmodel
+#' @method deviance spautor
+#' @export
+deviance.spautor <- deviance.splm
