@@ -10,7 +10,8 @@
 #'
 #' @return Printed fitted model objects and summaries with formatting.
 #'
-#' @method print spmod
+#' @name print.spmodel
+#' @method print splm
 #' @export
 #'
 #' @examples
@@ -21,7 +22,7 @@
 #' print(spmod)
 #' print(summary(spmod))
 #' print(anova(spmod))
-print.spmod <- function(x, digits = max(3L, getOption("digits") - 3L),
+print.splm <- function(x, digits = max(3L, getOption("digits") - 3L),
                         ...) {
   cat("\nCall:\n", paste(deparse(x$call),
     sep = "\n",
@@ -39,29 +40,12 @@ print.spmod <- function(x, digits = max(3L, getOption("digits") - 3L),
   cat("\n")
 
   spcoef <- coef(x, type = "spcov")
-   if (x$fn == "splm") {
-    if (!x$anisotropy) {
-      spcoef <- spcoef[-which(names(spcoef) %in% c("rotate", "scale"))]
-    }
-    if (inherits(coef(x, type = "spcov"), "none")) {
-      spcoef <- spcoef["ie"]
-    }
+
+  if (!x$anisotropy) {
+    spcoef <- spcoef[-which(names(spcoef) %in% c("rotate", "scale"))]
   }
-
-
-
-  if (x$fn == "spautor") {
-    no_ie <- spcoef[["ie"]] == 0 && x$is_known$spcov[["ie"]]
-    no_extra <- spcoef[["extra"]] == 0 && x$is_known$spcov[["extra"]]
-    if (no_ie && no_extra) {
-      spcoef <- spcoef[c("de", "range")]
-    } else if (no_ie && !no_extra) {
-      spcoef <- spcoef[c("de", "range", "extra")]
-    } else if (!no_ie && no_extra) {
-      spcoef <- spcoef[c("de", "ie", "range")]
-    } else {
-      spcoef <- spcoef[c("de", "ie", "range", "extra")]
-    }
+  if (inherits(coef(x, type = "spcov"), "none")) {
+    spcoef <- spcoef["ie"]
   }
 
   cat(paste("\nCoefficients (", class(coef(x, type = "spcov")), " spatial covariance):\n", sep = ""))
@@ -83,11 +67,65 @@ print.spmod <- function(x, digits = max(3L, getOption("digits") - 3L),
   }
   invisible(x)
 }
-#' @rdname print.spmod
-#' @method print summary.spmod
-#' @importFrom stats quantile printCoefmat
+
+#' @rdname print.spmodel
+#' @method print spautor
 #' @export
-print.summary.spmod <- function(x,
+print.spautor <- function(x, digits = max(3L, getOption("digits") - 3L),
+                       ...) {
+  cat("\nCall:\n", paste(deparse(x$call),
+                         sep = "\n",
+                         collapse = "\n"
+  ), "\n\n", sep = "")
+
+  cat("\n")
+
+  cat("Coefficients (fixed):\n")
+  print.default(format(coef(x, type = "fixed"), digits = digits),
+                print.gap = 2L,
+                quote = FALSE
+  )
+
+  cat("\n")
+
+  spcoef <- coef(x, type = "spcov")
+
+  no_ie <- spcoef[["ie"]] == 0 && x$is_known$spcov[["ie"]]
+  no_extra <- spcoef[["extra"]] == 0 && x$is_known$spcov[["extra"]]
+  if (no_ie && no_extra) {
+    spcoef <- spcoef[c("de", "range")]
+  } else if (no_ie && !no_extra) {
+    spcoef <- spcoef[c("de", "range", "extra")]
+  } else if (!no_ie && no_extra) {
+    spcoef <- spcoef[c("de", "ie", "range")]
+  } else {
+    spcoef <- spcoef[c("de", "ie", "range", "extra")]
+  }
+
+  cat(paste("\nCoefficients (", class(coef(x, type = "spcov")), " spatial covariance):\n", sep = ""))
+  print.default(format(spcoef, digits = digits),
+                print.gap = 2L,
+                quote = FALSE
+  )
+
+  cat("\n")
+
+  if (length(coef(x, type = "randcov"))) {
+    cat("Coefficients (random effects):\n")
+    print.default(format(coef(x, type = "randcov"), digits = digits),
+                  print.gap = 2L,
+                  quote = FALSE
+    )
+
+    cat("\n")
+  }
+  invisible(x)
+}
+
+#' @rdname print.spmodel
+#' @method print summary.splm
+#' @export
+print.summary.splm <- function(x,
                                 digits = max(3L, getOption("digits") - 3L),
                                 signif.stars = getOption("show.signif.stars"),
                                 ...) {
@@ -97,8 +135,8 @@ print.summary.spmod <- function(x,
   # pasting the residual summary
   cat("\nResiduals:\n")
   resQ <- c(
-    min(x$residuals$raw), quantile(x$residuals$raw, p = c(0.25, 0.5, 0.75), na.rm = TRUE),
-    max(x$residuals$raw)
+    min(x$residuals$response), quantile(x$residuals$response, p = c(0.25, 0.5, 0.75), na.rm = TRUE),
+    max(x$residuals$response)
   )
   names(resQ) <- c("Min", "1Q", "Median", "3Q", "Max")
   print(resQ, digits = digits)
@@ -120,28 +158,14 @@ print.summary.spmod <- function(x,
   # pasting the covariance coefficient summary
   spcoef <- x$coefficients$spcov
 
-  if (x$fn == "splm") {
-    if (!x$anisotropy) {
-      spcoef <- spcoef[-which(names(spcoef) %in% c("rotate", "scale"))]
-    }
-    if (inherits(x$coefficients$spcov, "none")) {
-      spcoef <- spcoef["ie"]
-    }
+
+  if (!x$anisotropy) {
+    spcoef <- spcoef[-which(names(spcoef) %in% c("rotate", "scale"))]
+  }
+  if (inherits(x$coefficients$spcov, "none")) {
+    spcoef <- spcoef["ie"]
   }
 
-  if (x$fn == "spautor") {
-    no_ie <- spcoef[["ie"]] == 0 && x$is_known$spcov[["ie"]]
-    no_extra <- spcoef[["extra"]] == 0 && x$is_known$spcov[["extra"]]
-    if (no_ie && no_extra) {
-      spcoef <- spcoef[c("de", "range")]
-    } else if (no_ie && !no_extra) {
-      spcoef <- spcoef[c("de", "range", "extra")]
-    } else if (!no_ie && no_extra) {
-      spcoef <- spcoef[c("de", "ie", "range")]
-    } else {
-      spcoef <- spcoef[c("de", "ie", "range", "extra")]
-    }
-  }
 
   cat(paste("\nCoefficients (", class(x$coefficients$spcov), " spatial covariance):\n", sep = ""))
   print(spcoef, digits = digits)
@@ -155,10 +179,72 @@ print.summary.spmod <- function(x,
   invisible(x)
 }
 
-#' @rdname print.spmod
-#' @method print anova.spmod
+#' @rdname print.spmodel
+#' @method print summary.spautor
 #' @export
-print.anova.spmod <- function(x, digits = max(getOption("digits") - 2L, 3L),
+print.summary.spautor <- function(x,
+                               digits = max(3L, getOption("digits") - 3L),
+                               signif.stars = getOption("show.signif.stars"),
+                               ...) {
+  # pasting the formula call
+  cat("\nCall:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"), "\n", sep = "")
+
+  # pasting the residual summary
+  cat("\nResiduals:\n")
+  resQ <- c(
+    min(x$residuals$response), quantile(x$residuals$response, p = c(0.25, 0.5, 0.75), na.rm = TRUE),
+    max(x$residuals$response)
+  )
+  names(resQ) <- c("Min", "1Q", "Median", "3Q", "Max")
+  print(resQ, digits = digits)
+
+  # pasting the fixed coefficient summary
+  cat("\nCoefficients (fixed):\n")
+  coefs_fixed <- x$coefficients$fixed
+  # colnames(coefs_fixed) <- c("Estimate", "Std. Error", "t value", "Pr(>|t|)")
+  colnames(coefs_fixed) <- c("Estimate", "Std. Error", "z value", "Pr(>|z|)")
+  printCoefmat(coefs_fixed, digits = digits, signif.stars = signif.stars, na.print = "NA", ...)
+
+  # pasting the generalized r squared
+  if (x$pseudoR2 != 0) {
+    cat("\nPseudo R-squared: ")
+    cat(formatC(x$pseudoR2, digits = digits))
+    cat("\n")
+  }
+
+  # pasting the covariance coefficient summary
+  spcoef <- x$coefficients$spcov
+
+
+  no_ie <- spcoef[["ie"]] == 0 && x$is_known$spcov[["ie"]]
+  no_extra <- spcoef[["extra"]] == 0 && x$is_known$spcov[["extra"]]
+  if (no_ie && no_extra) {
+    spcoef <- spcoef[c("de", "range")]
+  } else if (no_ie && !no_extra) {
+    spcoef <- spcoef[c("de", "range", "extra")]
+  } else if (!no_ie && no_extra) {
+    spcoef <- spcoef[c("de", "ie", "range")]
+  } else {
+    spcoef <- spcoef[c("de", "ie", "range", "extra")]
+  }
+
+
+  cat(paste("\nCoefficients (", class(x$coefficients$spcov), " spatial covariance):\n", sep = ""))
+  print(spcoef, digits = digits)
+
+  if (length(x$coefficients$randcov)) {
+    cat("\nCoefficients (random effects):\n")
+    print(x$coefficients$randcov, digits = digits)
+    cat("\n")
+  }
+
+  invisible(x)
+}
+
+#' @rdname print.spmodel
+#' @method print anova.splm
+#' @export
+print.anova.splm <- function(x, digits = max(getOption("digits") - 2L, 3L),
                               signif.stars = getOption("show.signif.stars"), ...) {
   cat(attr(x, "heading")[1])
   cat("\n")
@@ -173,3 +259,8 @@ print.anova.spmod <- function(x, digits = max(getOption("digits") - 2L, 3L),
   }
   printCoefmat(x, digits = digits, signif.stars = signif.stars, P.values = P.values, has.Pvalue = has.Pvalue, ...)
 }
+
+#' @rdname print.spmodel
+#' @method print anova.spautor
+#' @export
+print.anova.spautor <- print.anova.splm
