@@ -203,8 +203,8 @@
 #'
 #' @return A list with many elements that store information about
 #'   the fitted model object. If \code{spcov_type} or \code{spcov_initial} are
-#'   length one, the list has class \code{spmod}. Many generic functions that
-#'   summarize model fit are available for \code{spmod} objects, including
+#'   length one, the list has class \code{splm}. Many generic functions that
+#'   summarize model fit are available for \code{splm} objects, including
 #'   \code{AIC}, \code{AICc}, \code{anova}, \code{augment}, \code{coef},
 #'   \code{cooks.distance}, \code{deviance}, \code{fitted}, \code{formula},
 #'   \code{glance}, \code{glances}, \code{hatvalues}, \code{influence},
@@ -212,9 +212,9 @@
 #'   \code{plot}, \code{predict}, \code{print}, \code{pseudoR2}, \code{summary},
 #'   \code{terms}, \code{tidy}, \code{update}, and \code{vcov}. If
 #'   \code{spcov_type} or \code{spcov_initial} are length greater than one, the
-#'   list has class \code{spmod_list} and each element in the list has class
-#'   \code{spmod}. \code{glances} can be used to summarize \code{spmod_list}
-#'   objects, and the aforementioned \code{spmod} generics can be used on each
+#'   list has class \code{splm_list} and each element in the list has class
+#'   \code{splm}. \code{glances} can be used to summarize \code{splm_list}
+#'   objects, and the aforementioned \code{splm} generics can be used on each
 #'   individual list element (model fit).
 #'
 #' @note This function does not perform any internal scaling. If optimization is not
@@ -252,7 +252,7 @@ splm <- function(formula, data, spcov_type, xcoord, ycoord, spcov_initial, estme
       do.call("splm", call_list, envir = penv)
     })
     names(splm_out) <- paste("spcov_initial", seq_along(spcov_initial), sep = "_")
-    new_splm_out <- structure(splm_out, class = "spmod_list")
+    new_splm_out <- structure(splm_out, class = "splm_list")
     return(new_splm_out)
   } else if (!missing(spcov_type) && length(spcov_type) > 1) {
     call_list <- as.list(match.call())[-1]
@@ -262,7 +262,7 @@ splm <- function(formula, data, spcov_type, xcoord, ycoord, spcov_initial, estme
       do.call("splm", call_list, envir = penv)
     })
     names(splm_out) <- spcov_type
-    new_splm_out <- structure(splm_out, class = "spmod_list")
+    new_splm_out <- structure(splm_out, class = "splm_list")
     return(new_splm_out)
   }
 
@@ -365,7 +365,6 @@ splm <- function(formula, data, spcov_type, xcoord, ycoord, spcov_initial, estme
     formula = formula,
     terms = data_object$terms,
     call = match.call(),
-    fn = "splm",
     estmethod = estmethod,
     obdata = data_object$obdata,
     newdata = data_object$newdata,
@@ -388,6 +387,6 @@ splm <- function(formula, data, spcov_type, xcoord, ycoord, spcov_initial, estme
     crs = data_object$crs
   )
 
-  new_output <- structure(output, class = "spmod")
+  new_output <- structure(output, class = "splm")
   new_output
 }
