@@ -8,6 +8,8 @@
 #' @return The variance-covariance matrix of coefficients obtained via \code{coef()}.
 #'   Currently, only the variance-covariance matrix of the fixed effects is supported.
 #'
+#' @name vcov.spmodel
+#' @method vcov splm
 #' @export
 #'
 #' @examples
@@ -16,9 +18,14 @@
 #'   spcov_type = "exponential", xcoord = x, ycoord = y
 #' )
 #' vcov(spmod)
-vcov.spmod <- function(object, ...) {
+vcov.splm <- function(object, ...) {
   type <- "fixed"
   if (type == "fixed") {
     return(object$vcov$fixed)
   }
 }
+
+#' @rdname vcov.spmodel
+#' @method vcov spautor
+#' @export
+vcov.spautor <- vcov.splm
